@@ -27,7 +27,7 @@ gboolean tp_cli_channel_run_close (TpChannel *proxy,
 
 
 typedef void (*tp_cli_channel_callback_for_get_channel_type) (TpChannel *proxy,
-    const gchar *out0,
+    const gchar *out_Channel_Type,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -40,14 +40,14 @@ TpProxyPendingCall *tp_cli_channel_call_get_channel_type (TpChannel *proxy,
 
 gboolean tp_cli_channel_run_get_channel_type (TpChannel *proxy,
     gint timeout_ms,
-    gchar **out0,
+    gchar **out_Channel_Type,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_callback_for_get_handle) (TpChannel *proxy,
-    guint out0,
-    guint out1,
+    guint out_Target_Handle_Type,
+    guint out_Target_Handle,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -60,14 +60,14 @@ TpProxyPendingCall *tp_cli_channel_call_get_handle (TpChannel *proxy,
 
 gboolean tp_cli_channel_run_get_handle (TpChannel *proxy,
     gint timeout_ms,
-    guint *out0,
-    guint *out1,
+    guint *out_Target_Handle_Type,
+    guint *out_Target_Handle,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_callback_for_get_interfaces) (TpChannel *proxy,
-    const gchar **out0,
+    const gchar **out_Interfaces,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -80,7 +80,7 @@ TpProxyPendingCall *tp_cli_channel_call_get_interfaces (TpChannel *proxy,
 
 gboolean tp_cli_channel_run_get_interfaces (TpChannel *proxy,
     gint timeout_ms,
-    gchar ***out0,
+    gchar ***out_Interfaces,
     GError **error,
     GMainLoop **loop);
 
@@ -286,9 +286,9 @@ gboolean tp_cli_channel_interface_group_run_add_members (TpChannel *proxy,
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_all_members) (TpChannel *proxy,
-    const GArray *out0,
-    const GArray *out1,
-    const GArray *out2,
+    const GArray *out_Members,
+    const GArray *out_Local_Pending,
+    const GArray *out_Remote_Pending,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -301,15 +301,15 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_all_members (TpChann
 
 gboolean tp_cli_channel_interface_group_run_get_all_members (TpChannel *proxy,
     gint timeout_ms,
-    GArray **out0,
-    GArray **out1,
-    GArray **out2,
+    GArray **out_Members,
+    GArray **out_Local_Pending,
+    GArray **out_Remote_Pending,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_group_flags) (TpChannel *proxy,
-    guint out0,
+    guint out_Group_Flags,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -322,13 +322,13 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_group_flags (TpChann
 
 gboolean tp_cli_channel_interface_group_run_get_group_flags (TpChannel *proxy,
     gint timeout_ms,
-    guint *out0,
+    guint *out_Group_Flags,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_handle_owners) (TpChannel *proxy,
-    const GArray *out0,
+    const GArray *out_Owners,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -343,13 +343,13 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_handle_owners (TpCha
 gboolean tp_cli_channel_interface_group_run_get_handle_owners (TpChannel *proxy,
     gint timeout_ms,
     const GArray *in_Handles,
-    GArray **out0,
+    GArray **out_Owners,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_local_pending_members) (TpChannel *proxy,
-    const GArray *out0,
+    const GArray *out_Handles,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -362,13 +362,13 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_local_pending_member
 
 gboolean tp_cli_channel_interface_group_run_get_local_pending_members (TpChannel *proxy,
     gint timeout_ms,
-    GArray **out0,
+    GArray **out_Handles,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_local_pending_members_with_info) (TpChannel *proxy,
-    const GPtrArray *out0,
+    const GPtrArray *out_Info,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -381,13 +381,13 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_local_pending_member
 
 gboolean tp_cli_channel_interface_group_run_get_local_pending_members_with_info (TpChannel *proxy,
     gint timeout_ms,
-    GPtrArray **out0,
+    GPtrArray **out_Info,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_members) (TpChannel *proxy,
-    const GArray *out0,
+    const GArray *out_Handles,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -400,13 +400,13 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_members (TpChannel *
 
 gboolean tp_cli_channel_interface_group_run_get_members (TpChannel *proxy,
     gint timeout_ms,
-    GArray **out0,
+    GArray **out_Handles,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_remote_pending_members) (TpChannel *proxy,
-    const GArray *out0,
+    const GArray *out_Handles,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -419,13 +419,13 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_remote_pending_membe
 
 gboolean tp_cli_channel_interface_group_run_get_remote_pending_members (TpChannel *proxy,
     gint timeout_ms,
-    GArray **out0,
+    GArray **out_Handles,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_interface_group_callback_for_get_self_handle) (TpChannel *proxy,
-    guint out0,
+    guint out_Self_Handle,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -438,7 +438,7 @@ TpProxyPendingCall *tp_cli_channel_interface_group_call_get_self_handle (TpChann
 
 gboolean tp_cli_channel_interface_group_run_get_self_handle (TpChannel *proxy,
     gint timeout_ms,
-    guint *out0,
+    guint *out_Self_Handle,
     GError **error,
     GMainLoop **loop);
 
@@ -550,7 +550,7 @@ TpProxySignalConnection *tp_cli_channel_interface_media_signalling_connect_to_ne
     GError **error);
 
 typedef void (*tp_cli_channel_interface_media_signalling_callback_for_get_session_handlers) (TpChannel *proxy,
-    const GPtrArray *out0,
+    const GPtrArray *out_Session_Handlers,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -563,7 +563,7 @@ TpProxyPendingCall *tp_cli_channel_interface_media_signalling_call_get_session_h
 
 gboolean tp_cli_channel_interface_media_signalling_run_get_session_handlers (TpChannel *proxy,
     gint timeout_ms,
-    GPtrArray **out0,
+    GPtrArray **out_Session_Handlers,
     GError **error,
     GMainLoop **loop);
 
@@ -601,7 +601,7 @@ TpProxySignalConnection *tp_cli_channel_interface_messages_connect_to_message_re
     GError **error);
 
 typedef void (*tp_cli_channel_interface_messages_callback_for_send_message) (TpChannel *proxy,
-    const gchar *out0,
+    const gchar *out_Token,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -618,7 +618,7 @@ gboolean tp_cli_channel_interface_messages_run_send_message (TpChannel *proxy,
     gint timeout_ms,
     const GPtrArray *in_Message,
     guint in_Flags,
-    gchar **out0,
+    gchar **out_Token,
     GError **error,
     GMainLoop **loop);
 
@@ -658,7 +658,7 @@ TpProxySignalConnection *tp_cli_channel_interface_password_connect_to_password_f
     GError **error);
 
 typedef void (*tp_cli_channel_interface_password_callback_for_get_password_flags) (TpChannel *proxy,
-    guint out0,
+    guint out_Password_Flags,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -671,13 +671,13 @@ TpProxyPendingCall *tp_cli_channel_interface_password_call_get_password_flags (T
 
 gboolean tp_cli_channel_interface_password_run_get_password_flags (TpChannel *proxy,
     gint timeout_ms,
-    guint *out0,
+    guint *out_Password_Flags,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_interface_password_callback_for_provide_password) (TpChannel *proxy,
-    gboolean out0,
+    gboolean out_Correct,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -692,7 +692,155 @@ TpProxyPendingCall *tp_cli_channel_interface_password_call_provide_password (TpC
 gboolean tp_cli_channel_interface_password_run_provide_password (TpChannel *proxy,
     gint timeout_ms,
     const gchar *in_Password,
-    gboolean *out0,
+    gboolean *out_Correct,
+    GError **error,
+    GMainLoop **loop);
+
+
+typedef void (*tp_cli_channel_interface_tube_signal_callback_tube_channel_state_changed) (TpChannel *proxy,
+    guint arg_State,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_interface_tube_connect_to_tube_channel_state_changed (TpChannel *proxy,
+    tp_cli_channel_interface_tube_signal_callback_tube_channel_state_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_dbus_tube_signal_callback_dbus_names_changed) (TpChannel *proxy,
+    GHashTable *arg_Added,
+    const GArray *arg_Removed,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_dbus_tube_connect_to_dbus_names_changed (TpChannel *proxy,
+    tp_cli_channel_type_dbus_tube_signal_callback_dbus_names_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_dbus_tube_callback_for_offer) (TpChannel *proxy,
+    const gchar *out_address,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_dbus_tube_call_offer (TpChannel *proxy,
+    gint timeout_ms,
+    GHashTable *in_parameters,
+    guint in_access_control,
+    tp_cli_channel_type_dbus_tube_callback_for_offer callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+gboolean tp_cli_channel_type_dbus_tube_run_offer (TpChannel *proxy,
+    gint timeout_ms,
+    GHashTable *in_parameters,
+    guint in_access_control,
+    gchar **out_address,
+    GError **error,
+    GMainLoop **loop);
+
+
+typedef void (*tp_cli_channel_type_dbus_tube_callback_for_accept) (TpChannel *proxy,
+    const gchar *out_address,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_dbus_tube_call_accept (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_access_control,
+    tp_cli_channel_type_dbus_tube_callback_for_accept callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+gboolean tp_cli_channel_type_dbus_tube_run_accept (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_access_control,
+    gchar **out_address,
+    GError **error,
+    GMainLoop **loop);
+
+
+typedef void (*tp_cli_channel_type_file_transfer_signal_callback_file_transfer_state_changed) (TpChannel *proxy,
+    guint arg_State,
+    guint arg_Reason,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_file_transfer_connect_to_file_transfer_state_changed (TpChannel *proxy,
+    tp_cli_channel_type_file_transfer_signal_callback_file_transfer_state_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_file_transfer_signal_callback_transferred_bytes_changed) (TpChannel *proxy,
+    guint64 arg_Count,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_file_transfer_connect_to_transferred_bytes_changed (TpChannel *proxy,
+    tp_cli_channel_type_file_transfer_signal_callback_transferred_bytes_changed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_file_transfer_signal_callback_initial_offset_defined) (TpChannel *proxy,
+    guint64 arg_InitialOffset,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_file_transfer_connect_to_initial_offset_defined (TpChannel *proxy,
+    tp_cli_channel_type_file_transfer_signal_callback_initial_offset_defined callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_file_transfer_callback_for_accept_file) (TpChannel *proxy,
+    const GValue *out_Address,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_file_transfer_call_accept_file (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_Address_Type,
+    guint in_Access_Control,
+    const GValue *in_Access_Control_Param,
+    guint64 in_Offset,
+    tp_cli_channel_type_file_transfer_callback_for_accept_file callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+gboolean tp_cli_channel_type_file_transfer_run_accept_file (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_Address_Type,
+    guint in_Access_Control,
+    const GValue *in_Access_Control_Param,
+    guint64 in_Offset,
+    GValue **out_Address,
+    GError **error,
+    GMainLoop **loop);
+
+
+typedef void (*tp_cli_channel_type_file_transfer_callback_for_provide_file) (TpChannel *proxy,
+    const GValue *out_Address,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_file_transfer_call_provide_file (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_Address_Type,
+    guint in_Access_Control,
+    const GValue *in_Access_Control_Param,
+    tp_cli_channel_type_file_transfer_callback_for_provide_file callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+gboolean tp_cli_channel_type_file_transfer_run_provide_file (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_Address_Type,
+    guint in_Access_Control,
+    const GValue *in_Access_Control_Param,
+    GValue **out_Address,
     GError **error,
     GMainLoop **loop);
 
@@ -718,7 +866,7 @@ TpProxySignalConnection *tp_cli_channel_type_room_list_connect_to_listing_rooms
     GError **error);
 
 typedef void (*tp_cli_channel_type_room_list_callback_for_get_listing_rooms) (TpChannel *proxy,
-    gboolean out0,
+    gboolean out_In_Progress,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -731,7 +879,7 @@ TpProxyPendingCall *tp_cli_channel_type_room_list_call_get_listing_rooms (TpChan
 
 gboolean tp_cli_channel_type_room_list_run_get_listing_rooms (TpChannel *proxy,
     gint timeout_ms,
-    gboolean *out0,
+    gboolean *out_In_Progress,
     GError **error,
     GMainLoop **loop);
 
@@ -770,6 +918,90 @@ gboolean tp_cli_channel_type_room_list_run_stop_listing (TpChannel *proxy,
     GMainLoop **loop);
 
 
+typedef void (*tp_cli_channel_type_stream_tube_signal_callback_new_remote_connection) (TpChannel *proxy,
+    guint arg_Handle,
+    const GValue *arg_Connection_Param,
+    guint arg_Connection_ID,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_stream_tube_connect_to_new_remote_connection (TpChannel *proxy,
+    tp_cli_channel_type_stream_tube_signal_callback_new_remote_connection callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_stream_tube_signal_callback_new_local_connection) (TpChannel *proxy,
+    guint arg_Connection_ID,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_stream_tube_connect_to_new_local_connection (TpChannel *proxy,
+    tp_cli_channel_type_stream_tube_signal_callback_new_local_connection callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_stream_tube_signal_callback_connection_closed) (TpChannel *proxy,
+    guint arg_Connection_ID,
+    const gchar *arg_Error,
+    const gchar *arg_Message,
+    gpointer user_data, GObject *weak_object);
+TpProxySignalConnection *tp_cli_channel_type_stream_tube_connect_to_connection_closed (TpChannel *proxy,
+    tp_cli_channel_type_stream_tube_signal_callback_connection_closed callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object,
+    GError **error);
+
+typedef void (*tp_cli_channel_type_stream_tube_callback_for_offer) (TpChannel *proxy,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_stream_tube_call_offer (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_address_type,
+    const GValue *in_address,
+    guint in_access_control,
+    GHashTable *in_parameters,
+    tp_cli_channel_type_stream_tube_callback_for_offer callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+gboolean tp_cli_channel_type_stream_tube_run_offer (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_address_type,
+    const GValue *in_address,
+    guint in_access_control,
+    GHashTable *in_parameters,
+    GError **error,
+    GMainLoop **loop);
+
+
+typedef void (*tp_cli_channel_type_stream_tube_callback_for_accept) (TpChannel *proxy,
+    const GValue *out_address,
+    const GError *error, gpointer user_data,
+    GObject *weak_object);
+
+TpProxyPendingCall *tp_cli_channel_type_stream_tube_call_accept (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_address_type,
+    guint in_access_control,
+    const GValue *in_access_control_param,
+    tp_cli_channel_type_stream_tube_callback_for_accept callback,
+    gpointer user_data,
+    GDestroyNotify destroy,
+    GObject *weak_object);
+
+gboolean tp_cli_channel_type_stream_tube_run_accept (TpChannel *proxy,
+    gint timeout_ms,
+    guint in_address_type,
+    guint in_access_control,
+    const GValue *in_access_control_param,
+    GValue **out_address,
+    GError **error,
+    GMainLoop **loop);
+
+
 typedef void (*tp_cli_channel_type_streamed_media_signal_callback_stream_added) (TpChannel *proxy,
     guint arg_Stream_ID,
     guint arg_Contact_Handle,
@@ -828,7 +1060,7 @@ TpProxySignalConnection *tp_cli_channel_type_streamed_media_connect_to_stream_st
     GError **error);
 
 typedef void (*tp_cli_channel_type_streamed_media_callback_for_list_streams) (TpChannel *proxy,
-    const GPtrArray *out0,
+    const GPtrArray *out_Streams,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -841,7 +1073,7 @@ TpProxyPendingCall *tp_cli_channel_type_streamed_media_call_list_streams (TpChan
 
 gboolean tp_cli_channel_type_streamed_media_run_list_streams (TpChannel *proxy,
     gint timeout_ms,
-    GPtrArray **out0,
+    GPtrArray **out_Streams,
     GError **error,
     GMainLoop **loop);
 
@@ -887,7 +1119,7 @@ gboolean tp_cli_channel_type_streamed_media_run_request_stream_direction (TpChan
 
 
 typedef void (*tp_cli_channel_type_streamed_media_callback_for_request_streams) (TpChannel *proxy,
-    const GPtrArray *out0,
+    const GPtrArray *out_Streams,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -904,7 +1136,7 @@ gboolean tp_cli_channel_type_streamed_media_run_request_streams (TpChannel *prox
     gint timeout_ms,
     guint in_Contact_Handle,
     const GArray *in_Types,
-    GPtrArray **out0,
+    GPtrArray **out_Streams,
     GError **error,
     GMainLoop **loop);
 
@@ -978,7 +1210,7 @@ gboolean tp_cli_channel_type_text_run_acknowledge_pending_messages (TpChannel *p
 
 
 typedef void (*tp_cli_channel_type_text_callback_for_get_message_types) (TpChannel *proxy,
-    const GArray *out0,
+    const GArray *out_Available_Types,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -991,13 +1223,13 @@ TpProxyPendingCall *tp_cli_channel_type_text_call_get_message_types (TpChannel *
 
 gboolean tp_cli_channel_type_text_run_get_message_types (TpChannel *proxy,
     gint timeout_ms,
-    GArray **out0,
+    GArray **out_Available_Types,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_type_text_callback_for_list_pending_messages) (TpChannel *proxy,
-    const GPtrArray *out0,
+    const GPtrArray *out_Pending_Messages,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -1012,7 +1244,7 @@ TpProxyPendingCall *tp_cli_channel_type_text_call_list_pending_messages (TpChann
 gboolean tp_cli_channel_type_text_run_list_pending_messages (TpChannel *proxy,
     gint timeout_ms,
     gboolean in_Clear,
-    GPtrArray **out0,
+    GPtrArray **out_Pending_Messages,
     GError **error,
     GMainLoop **loop);
 
@@ -1098,7 +1330,7 @@ TpProxySignalConnection *tp_cli_channel_type_tubes_connect_to_stream_tube_new_co
     GError **error);
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_get_available_stream_tube_types) (TpChannel *proxy,
-    GHashTable *out0,
+    GHashTable *out_Available_Stream_Tube_Types,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -1111,13 +1343,13 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_get_available_stream_tube_typ
 
 gboolean tp_cli_channel_type_tubes_run_get_available_stream_tube_types (TpChannel *proxy,
     gint timeout_ms,
-    GHashTable **out0,
+    GHashTable **out_Available_Stream_Tube_Types,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_get_available_tube_types) (TpChannel *proxy,
-    const GArray *out0,
+    const GArray *out_Available_Tube_Types,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -1130,13 +1362,13 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_get_available_tube_types (TpC
 
 gboolean tp_cli_channel_type_tubes_run_get_available_tube_types (TpChannel *proxy,
     gint timeout_ms,
-    GArray **out0,
+    GArray **out_Available_Tube_Types,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_list_tubes) (TpChannel *proxy,
-    const GPtrArray *out0,
+    const GPtrArray *out_Tubes,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -1149,13 +1381,13 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_list_tubes (TpChannel *proxy,
 
 gboolean tp_cli_channel_type_tubes_run_list_tubes (TpChannel *proxy,
     gint timeout_ms,
-    GPtrArray **out0,
+    GPtrArray **out_Tubes,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_offer_d_bus_tube) (TpChannel *proxy,
-    guint out0,
+    guint out_Tube_ID,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -1172,13 +1404,13 @@ gboolean tp_cli_channel_type_tubes_run_offer_d_bus_tube (TpChannel *proxy,
     gint timeout_ms,
     const gchar *in_Service,
     GHashTable *in_Parameters,
-    guint *out0,
+    guint *out_Tube_ID,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_offer_stream_tube) (TpChannel *proxy,
-    guint out0,
+    guint out_Tube_ID,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -1203,7 +1435,7 @@ gboolean tp_cli_channel_type_tubes_run_offer_stream_tube (TpChannel *proxy,
     const GValue *in_Address,
     guint in_Access_Control,
     const GValue *in_Access_Control_Param,
-    guint *out0,
+    guint *out_Tube_ID,
     GError **error,
     GMainLoop **loop);
 
@@ -1276,7 +1508,7 @@ gboolean tp_cli_channel_type_tubes_run_close_tube (TpChannel *proxy,
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_get_d_bus_tube_address) (TpChannel *proxy,
-    const gchar *out0,
+    const gchar *out_Address,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -1291,13 +1523,13 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_get_d_bus_tube_address (TpCha
 gboolean tp_cli_channel_type_tubes_run_get_d_bus_tube_address (TpChannel *proxy,
     gint timeout_ms,
     guint in_ID,
-    gchar **out0,
+    gchar **out_Address,
     GError **error,
     GMainLoop **loop);
 
 
 typedef void (*tp_cli_channel_type_tubes_callback_for_get_d_bus_names) (TpChannel *proxy,
-    const GPtrArray *out0,
+    const GPtrArray *out_DBus_Names,
     const GError *error, gpointer user_data,
     GObject *weak_object);
 
@@ -1312,7 +1544,7 @@ TpProxyPendingCall *tp_cli_channel_type_tubes_call_get_d_bus_names (TpChannel *p
 gboolean tp_cli_channel_type_tubes_run_get_d_bus_names (TpChannel *proxy,
     gint timeout_ms,
     guint in_ID,
-    GPtrArray **out0,
+    GPtrArray **out_DBus_Names,
     GError **error,
     GMainLoop **loop);
 
