@@ -73,7 +73,7 @@ void tp_svc_connection_implement_get_interfaces (TpSvcConnectionClass *klass, tp
 /**
  * tp_svc_connection_return_from_get_interfaces:
  * @context: The D-Bus method invocation context
- * @out0: const gchar ** (FIXME, generate documentation)
+ * @out_Interfaces: const gchar ** (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -81,13 +81,13 @@ void tp_svc_connection_implement_get_interfaces (TpSvcConnectionClass *klass, tp
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_return_from_get_interfaces (DBusGMethodInvocation *context,
-    const gchar **out0);
+    const gchar **out_Interfaces);
 static inline void
 tp_svc_connection_return_from_get_interfaces (DBusGMethodInvocation *context,
-    const gchar **out0)
+    const gchar **out_Interfaces)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Interfaces);
 }
 
 typedef void (*tp_svc_connection_get_protocol_impl) (TpSvcConnection *self,
@@ -96,7 +96,7 @@ void tp_svc_connection_implement_get_protocol (TpSvcConnectionClass *klass, tp_s
 /**
  * tp_svc_connection_return_from_get_protocol:
  * @context: The D-Bus method invocation context
- * @out0: const gchar * (FIXME, generate documentation)
+ * @out_Protocol: const gchar * (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -104,13 +104,13 @@ void tp_svc_connection_implement_get_protocol (TpSvcConnectionClass *klass, tp_s
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_return_from_get_protocol (DBusGMethodInvocation *context,
-    const gchar *out0);
+    const gchar *out_Protocol);
 static inline void
 tp_svc_connection_return_from_get_protocol (DBusGMethodInvocation *context,
-    const gchar *out0)
+    const gchar *out_Protocol)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Protocol);
 }
 
 typedef void (*tp_svc_connection_get_self_handle_impl) (TpSvcConnection *self,
@@ -119,7 +119,7 @@ void tp_svc_connection_implement_get_self_handle (TpSvcConnectionClass *klass, t
 /**
  * tp_svc_connection_return_from_get_self_handle:
  * @context: The D-Bus method invocation context
- * @out0: guint  (FIXME, generate documentation)
+ * @out_Self_Handle: guint  (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -127,13 +127,13 @@ void tp_svc_connection_implement_get_self_handle (TpSvcConnectionClass *klass, t
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_return_from_get_self_handle (DBusGMethodInvocation *context,
-    guint out0);
+    guint out_Self_Handle);
 static inline void
 tp_svc_connection_return_from_get_self_handle (DBusGMethodInvocation *context,
-    guint out0)
+    guint out_Self_Handle)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Self_Handle);
 }
 
 typedef void (*tp_svc_connection_get_status_impl) (TpSvcConnection *self,
@@ -142,7 +142,7 @@ void tp_svc_connection_implement_get_status (TpSvcConnectionClass *klass, tp_svc
 /**
  * tp_svc_connection_return_from_get_status:
  * @context: The D-Bus method invocation context
- * @out0: guint  (FIXME, generate documentation)
+ * @out_Status: guint  (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -150,13 +150,13 @@ void tp_svc_connection_implement_get_status (TpSvcConnectionClass *klass, tp_svc
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_return_from_get_status (DBusGMethodInvocation *context,
-    guint out0);
+    guint out_Status);
 static inline void
 tp_svc_connection_return_from_get_status (DBusGMethodInvocation *context,
-    guint out0)
+    guint out_Status)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Status);
 }
 
 typedef void (*tp_svc_connection_hold_handles_impl) (TpSvcConnection *self,
@@ -188,7 +188,7 @@ void tp_svc_connection_implement_inspect_handles (TpSvcConnectionClass *klass, t
 /**
  * tp_svc_connection_return_from_inspect_handles:
  * @context: The D-Bus method invocation context
- * @out0: const gchar ** (FIXME, generate documentation)
+ * @out_Identifiers: const gchar ** (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -196,13 +196,13 @@ void tp_svc_connection_implement_inspect_handles (TpSvcConnectionClass *klass, t
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_return_from_inspect_handles (DBusGMethodInvocation *context,
-    const gchar **out0);
+    const gchar **out_Identifiers);
 static inline void
 tp_svc_connection_return_from_inspect_handles (DBusGMethodInvocation *context,
-    const gchar **out0)
+    const gchar **out_Identifiers)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Identifiers);
 }
 
 typedef void (*tp_svc_connection_list_channels_impl) (TpSvcConnection *self,
@@ -211,7 +211,7 @@ void tp_svc_connection_implement_list_channels (TpSvcConnectionClass *klass, tp_
 /**
  * tp_svc_connection_return_from_list_channels:
  * @context: The D-Bus method invocation context
- * @out0: const GPtrArray * (FIXME, generate documentation)
+ * @out_Channel_Info: const GPtrArray * (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -219,13 +219,13 @@ void tp_svc_connection_implement_list_channels (TpSvcConnectionClass *klass, tp_
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_return_from_list_channels (DBusGMethodInvocation *context,
-    const GPtrArray *out0);
+    const GPtrArray *out_Channel_Info);
 static inline void
 tp_svc_connection_return_from_list_channels (DBusGMethodInvocation *context,
-    const GPtrArray *out0)
+    const GPtrArray *out_Channel_Info)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Channel_Info);
 }
 
 typedef void (*tp_svc_connection_release_handles_impl) (TpSvcConnection *self,
@@ -259,7 +259,7 @@ void tp_svc_connection_implement_request_channel (TpSvcConnectionClass *klass, t
 /**
  * tp_svc_connection_return_from_request_channel:
  * @context: The D-Bus method invocation context
- * @out0: const gchar * (FIXME, generate documentation)
+ * @out_Object_Path: const gchar * (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -267,13 +267,13 @@ void tp_svc_connection_implement_request_channel (TpSvcConnectionClass *klass, t
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_return_from_request_channel (DBusGMethodInvocation *context,
-    const gchar *out0);
+    const gchar *out_Object_Path);
 static inline void
 tp_svc_connection_return_from_request_channel (DBusGMethodInvocation *context,
-    const gchar *out0)
+    const gchar *out_Object_Path)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Object_Path);
 }
 
 typedef void (*tp_svc_connection_request_handles_impl) (TpSvcConnection *self,
@@ -284,7 +284,7 @@ void tp_svc_connection_implement_request_handles (TpSvcConnectionClass *klass, t
 /**
  * tp_svc_connection_return_from_request_handles:
  * @context: The D-Bus method invocation context
- * @out0: const GArray * (FIXME, generate documentation)
+ * @out_Handles: const GArray * (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -292,13 +292,13 @@ void tp_svc_connection_implement_request_handles (TpSvcConnectionClass *klass, t
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_return_from_request_handles (DBusGMethodInvocation *context,
-    const GArray *out0);
+    const GArray *out_Handles);
 static inline void
 tp_svc_connection_return_from_request_handles (DBusGMethodInvocation *context,
-    const GArray *out0)
+    const GArray *out_Handles)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Handles);
 }
 
 void tp_svc_connection_emit_self_handle_changed (gpointer instance,
@@ -309,6 +309,9 @@ void tp_svc_connection_emit_new_channel (gpointer instance,
     guint arg_Handle_Type,
     guint arg_Handle,
     gboolean arg_Suppress_Handler);
+void tp_svc_connection_emit_connection_error (gpointer instance,
+    const gchar *arg_Error,
+    GHashTable *arg_Details);
 void tp_svc_connection_emit_status_changed (gpointer instance,
     guint arg_Status,
     guint arg_Reason);
@@ -344,7 +347,7 @@ void tp_svc_connection_interface_aliasing_implement_get_alias_flags (TpSvcConnec
 /**
  * tp_svc_connection_interface_aliasing_return_from_get_alias_flags:
  * @context: The D-Bus method invocation context
- * @out0: guint  (FIXME, generate documentation)
+ * @out_Alias_Flags: guint  (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -352,13 +355,13 @@ void tp_svc_connection_interface_aliasing_implement_get_alias_flags (TpSvcConnec
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_interface_aliasing_return_from_get_alias_flags (DBusGMethodInvocation *context,
-    guint out0);
+    guint out_Alias_Flags);
 static inline void
 tp_svc_connection_interface_aliasing_return_from_get_alias_flags (DBusGMethodInvocation *context,
-    guint out0)
+    guint out_Alias_Flags)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Alias_Flags);
 }
 
 typedef void (*tp_svc_connection_interface_aliasing_request_aliases_impl) (TpSvcConnectionInterfaceAliasing *self,
@@ -368,7 +371,7 @@ void tp_svc_connection_interface_aliasing_implement_request_aliases (TpSvcConnec
 /**
  * tp_svc_connection_interface_aliasing_return_from_request_aliases:
  * @context: The D-Bus method invocation context
- * @out0: const gchar ** (FIXME, generate documentation)
+ * @out_Aliases: const gchar ** (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -376,13 +379,13 @@ void tp_svc_connection_interface_aliasing_implement_request_aliases (TpSvcConnec
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_interface_aliasing_return_from_request_aliases (DBusGMethodInvocation *context,
-    const gchar **out0);
+    const gchar **out_Aliases);
 static inline void
 tp_svc_connection_interface_aliasing_return_from_request_aliases (DBusGMethodInvocation *context,
-    const gchar **out0)
+    const gchar **out_Aliases)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Aliases);
 }
 
 typedef void (*tp_svc_connection_interface_aliasing_get_aliases_impl) (TpSvcConnectionInterfaceAliasing *self,
@@ -392,7 +395,7 @@ void tp_svc_connection_interface_aliasing_implement_get_aliases (TpSvcConnection
 /**
  * tp_svc_connection_interface_aliasing_return_from_get_aliases:
  * @context: The D-Bus method invocation context
- * @out0: GHashTable * (FIXME, generate documentation)
+ * @out_Aliases: GHashTable * (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -400,13 +403,13 @@ void tp_svc_connection_interface_aliasing_implement_get_aliases (TpSvcConnection
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_interface_aliasing_return_from_get_aliases (DBusGMethodInvocation *context,
-    GHashTable *out0);
+    GHashTable *out_Aliases);
 static inline void
 tp_svc_connection_interface_aliasing_return_from_get_aliases (DBusGMethodInvocation *context,
-    GHashTable *out0)
+    GHashTable *out_Aliases)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Aliases);
 }
 
 typedef void (*tp_svc_connection_interface_aliasing_set_aliases_impl) (TpSvcConnectionInterfaceAliasing *self,
@@ -463,12 +466,12 @@ void tp_svc_connection_interface_avatars_implement_get_avatar_requirements (TpSv
 /**
  * tp_svc_connection_interface_avatars_return_from_get_avatar_requirements:
  * @context: The D-Bus method invocation context
- * @out0: const gchar ** (FIXME, generate documentation)
- * @out1: guint  (FIXME, generate documentation)
- * @out2: guint  (FIXME, generate documentation)
- * @out3: guint  (FIXME, generate documentation)
- * @out4: guint  (FIXME, generate documentation)
- * @out5: guint  (FIXME, generate documentation)
+ * @out_MIME_Types: const gchar ** (FIXME, generate documentation)
+ * @out_Min_Width: guint  (FIXME, generate documentation)
+ * @out_Min_Height: guint  (FIXME, generate documentation)
+ * @out_Max_Width: guint  (FIXME, generate documentation)
+ * @out_Max_Height: guint  (FIXME, generate documentation)
+ * @out_Max_Bytes: guint  (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -476,28 +479,28 @@ void tp_svc_connection_interface_avatars_implement_get_avatar_requirements (TpSv
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_interface_avatars_return_from_get_avatar_requirements (DBusGMethodInvocation *context,
-    const gchar **out0,
-    guint out1,
-    guint out2,
-    guint out3,
-    guint out4,
-    guint out5);
+    const gchar **out_MIME_Types,
+    guint out_Min_Width,
+    guint out_Min_Height,
+    guint out_Max_Width,
+    guint out_Max_Height,
+    guint out_Max_Bytes);
 static inline void
 tp_svc_connection_interface_avatars_return_from_get_avatar_requirements (DBusGMethodInvocation *context,
-    const gchar **out0,
-    guint out1,
-    guint out2,
-    guint out3,
-    guint out4,
-    guint out5)
+    const gchar **out_MIME_Types,
+    guint out_Min_Width,
+    guint out_Min_Height,
+    guint out_Max_Width,
+    guint out_Max_Height,
+    guint out_Max_Bytes)
 {
   dbus_g_method_return (context,
-      out0,
-      out1,
-      out2,
-      out3,
-      out4,
-      out5);
+      out_MIME_Types,
+      out_Min_Width,
+      out_Min_Height,
+      out_Max_Width,
+      out_Max_Height,
+      out_Max_Bytes);
 }
 
 typedef void (*tp_svc_connection_interface_avatars_get_avatar_tokens_impl) (TpSvcConnectionInterfaceAvatars *self,
@@ -555,8 +558,8 @@ void tp_svc_connection_interface_avatars_implement_request_avatar (TpSvcConnecti
 /**
  * tp_svc_connection_interface_avatars_return_from_request_avatar:
  * @context: The D-Bus method invocation context
- * @out0: const GArray * (FIXME, generate documentation)
- * @out1: const gchar * (FIXME, generate documentation)
+ * @out_Data: const GArray * (FIXME, generate documentation)
+ * @out_MIME_Type: const gchar * (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -564,16 +567,16 @@ void tp_svc_connection_interface_avatars_implement_request_avatar (TpSvcConnecti
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_interface_avatars_return_from_request_avatar (DBusGMethodInvocation *context,
-    const GArray *out0,
-    const gchar *out1);
+    const GArray *out_Data,
+    const gchar *out_MIME_Type);
 static inline void
 tp_svc_connection_interface_avatars_return_from_request_avatar (DBusGMethodInvocation *context,
-    const GArray *out0,
-    const gchar *out1)
+    const GArray *out_Data,
+    const gchar *out_MIME_Type)
 {
   dbus_g_method_return (context,
-      out0,
-      out1);
+      out_Data,
+      out_MIME_Type);
 }
 
 typedef void (*tp_svc_connection_interface_avatars_request_avatars_impl) (TpSvcConnectionInterfaceAvatars *self,
@@ -682,7 +685,7 @@ void tp_svc_connection_interface_capabilities_implement_advertise_capabilities (
 /**
  * tp_svc_connection_interface_capabilities_return_from_advertise_capabilities:
  * @context: The D-Bus method invocation context
- * @out0: const GPtrArray * (FIXME, generate documentation)
+ * @out_Self_Capabilities: const GPtrArray * (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -690,13 +693,13 @@ void tp_svc_connection_interface_capabilities_implement_advertise_capabilities (
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_interface_capabilities_return_from_advertise_capabilities (DBusGMethodInvocation *context,
-    const GPtrArray *out0);
+    const GPtrArray *out_Self_Capabilities);
 static inline void
 tp_svc_connection_interface_capabilities_return_from_advertise_capabilities (DBusGMethodInvocation *context,
-    const GPtrArray *out0)
+    const GPtrArray *out_Self_Capabilities)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Self_Capabilities);
 }
 
 typedef void (*tp_svc_connection_interface_capabilities_get_capabilities_impl) (TpSvcConnectionInterfaceCapabilities *self,
@@ -706,7 +709,7 @@ void tp_svc_connection_interface_capabilities_implement_get_capabilities (TpSvcC
 /**
  * tp_svc_connection_interface_capabilities_return_from_get_capabilities:
  * @context: The D-Bus method invocation context
- * @out0: const GPtrArray * (FIXME, generate documentation)
+ * @out_Contact_Capabilities: const GPtrArray * (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -714,13 +717,13 @@ void tp_svc_connection_interface_capabilities_implement_get_capabilities (TpSvcC
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_interface_capabilities_return_from_get_capabilities (DBusGMethodInvocation *context,
-    const GPtrArray *out0);
+    const GPtrArray *out_Contact_Capabilities);
 static inline void
 tp_svc_connection_interface_capabilities_return_from_get_capabilities (DBusGMethodInvocation *context,
-    const GPtrArray *out0)
+    const GPtrArray *out_Contact_Capabilities)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Contact_Capabilities);
 }
 
 void tp_svc_connection_interface_capabilities_emit_capabilities_changed (gpointer instance,
@@ -873,7 +876,7 @@ void tp_svc_connection_interface_presence_implement_get_statuses (TpSvcConnectio
 /**
  * tp_svc_connection_interface_presence_return_from_get_statuses:
  * @context: The D-Bus method invocation context
- * @out0: GHashTable * (FIXME, generate documentation)
+ * @out_Available_Statuses: GHashTable * (FIXME, generate documentation)
  *
  * Return successfully by calling dbus_g_method_return().
  * This inline function exists only to provide type-safety.
@@ -881,13 +884,13 @@ void tp_svc_connection_interface_presence_implement_get_statuses (TpSvcConnectio
 static inline
 /* this comment is to stop gtkdoc realising this is static */
 void tp_svc_connection_interface_presence_return_from_get_statuses (DBusGMethodInvocation *context,
-    GHashTable *out0);
+    GHashTable *out_Available_Statuses);
 static inline void
 tp_svc_connection_interface_presence_return_from_get_statuses (DBusGMethodInvocation *context,
-    GHashTable *out0)
+    GHashTable *out_Available_Statuses)
 {
   dbus_g_method_return (context,
-      out0);
+      out_Available_Statuses);
 }
 
 typedef void (*tp_svc_connection_interface_presence_remove_status_impl) (TpSvcConnectionInterfacePresence *self,
